==> pc-ble-driver-debug-4.1.4-5-x86_64.pkg.tar.zst: usr/src/debug/pc-ble-driver/pc-ble-driver-4.1.4/test/softdevice_api/testcase_util.cpp <==
/*
 * Copyright (c) 2019 Nordic Semiconductor ASA
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 *   2. Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 *   3. Neither the name of Nordic Semiconductor ASA nor the names of other
 *   contributors to this software may be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 *   4. This software must only be used in or with a processor manufactured by Nordic
 *   Semiconductor ASA, or in or with a processor manufactured by a third party that
 *   is used in combination with a processor manufactured by Nordic Semiconductor.
 *
 *   5. Any software provided in binary or object form under this license must not be
 *   reverse engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

// Test framework
#include "catch2/catch.hpp"

// Test support
#include <test_environment.h>
#include <test_util.h>

#include <vector>

TEST_CASE("create random advertising packet")
{
    const auto advertisingHeaderSize = 2;
    std::vector<uint8_t> advertisingData;

    SECTION("append manufacturer specific data data")
    {
        const auto data = std::vector<uint8_t>{0, 1, 2, 3, 4};
        testutil::appendManufacturerSpecificData(advertisingData, data);
        REQUIRE(advertisingData.size() == (data.size() + advertisingHeaderSize));
        REQUIRE(advertisingData[0] == (1 + static_cast<uint8_t>(data.size())));
        REQUIRE(advertisingData[1] == BLE_GAP_AD_TYPE_MANUFACTURER_SPECIFIC_DATA);

        for (size_t i = 0; i < data.size(); i++)
        {
            REQUIRE(advertisingData[2 + i] == data[i]);
        }
    }

    SECTION("append advertising name")
    {
        const std::string name = "Unicorn";
        testutil::appendAdvertisingName(advertisingData, name);
        REQUIRE(advertisingData.size() == (name.size() + advertisingHeaderSize));
        REQUIRE(advertisingData[0] == (1 + static_cast<uint8_t>(name.length())));
        REQUIRE(advertisingData[1] == BLE_GAP_AD_TYPE_COMPLETE_LOCAL_NAME);

        for (size_t i = 0; i < name.length(); i++)
        {
            REQUIRE(advertisingData[advertisingHeaderSize + i] == name[i]);
        }
    }

    SECTION("create random advertising packet")
    {
        std::string advertisingName;
        std::vector<uint8_t> randomData;

        testutil::createRandomAdvertisingData(advertisingData, advertisingName, randomData);
        size_t offset = 0;

        REQUIRE(advertisingData[offset++] == (1 + static_cast<uint8_t>(advertisingName.size())));
        REQUIRE(advertisingData[offset++] ==
                static_cast<uint8_t>(BLE_GAP_AD_TYPE_COMPLETE_LOCAL_NAME));

        for (size_t i = offset; i < advertisingName.length(); i++)
        {
            REQUIRE(advertisingData[i + offset] == advertisingName[i]);
        }

        offset = offset + advertisingName.length();
        REQUIRE(advertisingData[offset++] == (1 + static_cast<uint8_t>(randomData.size())));
        REQUIRE(advertisingData[offset++] ==
                static_cast<uint8_t>(BLE_GAP_AD_TYPE_MANUFACTURER_SPECIFIC_DATA));

        for (size_t i = 0; i < randomData.size(); i++)
        {
            REQUIRE(advertisingData[offset + i] == randomData[i]);
        }

        REQUIRE(advertisingData.size() == (advertisingName.length() + advertisingHeaderSize +
                                           randomData.size() + advertisingHeaderSize));
    }
}

==> pc-ble-driver-debug-4.1.4-9-x86_64.pkg.tar.zst: usr/src/debug/pc-ble-driver/pc-ble-driver-4.1.4/test/softdevice_api/testcase_util.cpp <==
/*
 * Copyright (c) 2019 Nordic Semiconductor ASA
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 *   2. Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 *   3. Neither the name of Nordic Semiconductor ASA nor the names of other
 *   contributors to this software may be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 *   4. This software must only be used in or with a processor manufactured by Nordic
 *   Semiconductor ASA, or in or with a processor manufactured by a third party that
 *   is used in combination with a processor manufactured by Nordic Semiconductor.
 *
 *   5. Any software provided in binary or object form under this license must not be
 *   reverse engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

// Test framework
#include "catch2/catch_all.hpp"

// Test support
#include <test_environment.h>
#include <test_util.h>

#include <vector>

TEST_CASE("create random advertising packet")
{
    const auto advertisingHeaderSize = 2;
    std::vector<uint8_t> advertisingData;

    SECTION("append manufacturer specific data data")
    {
        const auto data = std::vector<uint8_t>{0, 1, 2, 3, 4};
        testutil::appendManufacturerSpecificData(advertisingData, data);
        REQUIRE(advertisingData.size() == (data.size() + advertisingHeaderSize));
        REQUIRE(advertisingData[0] == (1 + static_cast<uint8_t>(data.size())));
        REQUIRE(advertisingData[1] == BLE_GAP_AD_TYPE_MANUFACTURER_SPECIFIC_DATA);

        for (size_t i = 0; i < data.size(); i++)
        {
            REQUIRE(advertisingData[2 + i] == data[i]);
        }
    }

    SECTION("append advertising name")
    {
        const std::string name = "Unicorn";
        testutil::appendAdvertisingName(advertisingData, name);
        REQUIRE(advertisingData.size() == (name.size() + advertisingHeaderSize));
        REQUIRE(advertisingData[0] == (1 + static_cast<uint8_t>(name.length())));
        REQUIRE(advertisingData[1] == BLE_GAP_AD_TYPE_COMPLETE_LOCAL_NAME);

        for (size_t i = 0; i < name.length(); i++)
        {
            REQUIRE(advertisingData[advertisingHeaderSize + i] == name[i]);
        }
    }

    SECTION("create random advertising packet")
    {
        std::string advertisingName;
        std::vector<uint8_t> randomData;

        testutil::createRandomAdvertisingData(advertisingData, advertisingName, randomData);
        size_t offset = 0;

        REQUIRE(advertisingData[offset++] == (1 + static_cast<uint8_t>(advertisingName.size())));
        REQUIRE(advertisingData[offset++] ==
                static_cast<uint8_t>(BLE_GAP_AD_TYPE_COMPLETE_LOCAL_NAME));

        for (size_t i = offset; i < advertisingName.length(); i++)
        {
            REQUIRE(advertisingData[i + offset] == advertisingName[i]);
        }

        offset = offset + advertisingName.length();
        REQUIRE(advertisingData[offset++] == (1 + static_cast<uint8_t>(randomData.size())));
        REQUIRE(advertisingData[offset++] ==
                static_cast<uint8_t>(BLE_GAP_AD_TYPE_MANUFACTURER_SPECIFIC_DATA));

        for (size_t i = 0; i < randomData.size(); i++)
        {
            REQUIRE(advertisingData[offset + i] == randomData[i]);
        }

        REQUIRE(advertisingData.size() == (advertisingName.length() + advertisingHeaderSize +
                                           randomData.size() + advertisingHeaderSize));
    }
}
